pub struct ContextConfig {
pub epic_sibling_cap: usize,
pub epic_byte_cap: usize,
}Fields
epic_sibling_cap: usizeMaximum number of sibling tickets included in worker context bundles.
epic_byte_cap: usizeMaximum byte size of the context bundle injected into worker prompts.