pub struct LoggingConfig {
pub enabled: bool,
pub file: Option<PathBuf>,
}Fields
enabled: boolWhen true, apm writes a debug log file for each run.
file: Option<PathBuf>Path to the log file written when logging is enabled.