pub struct TicketConfig {
pub sections: Vec<TicketSection>,
}Expand description
Configuration for the sections that appear on every ticket, in order.
Defined in .apm/ticket.toml as [[ticket.sections]] blocks.
Fields
sections: Vec<TicketSection>Trait Implementations
Sourceimpl Debug for TicketConfig
impl Debug for TicketConfig
Sourceimpl Default for TicketConfig
impl Default for TicketConfig
Sourcefn default() -> TicketConfig
fn default() -> TicketConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TicketConfig
impl<'de> Deserialize<'de> for TicketConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TicketConfig
impl JsonSchema for TicketConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TicketConfig
impl RefUnwindSafe for TicketConfig
impl Send for TicketConfig
impl Sync for TicketConfig
impl Unpin for TicketConfig
impl UnsafeUnpin for TicketConfig
impl UnwindSafe for TicketConfig