close

Function close 

pub fn close(
    root: &Path,
    config: &Config,
    id_arg: &str,
    reason: Option<&str>,
    agent: &str,
    aggressive: bool,
) -> Result<Vec<String>>
Close a ticket from any state. Commits the change to the ticket branch, pushes it (non-fatal if no remote), then merges into the default branch so that apm clean can detect and remove the worktree.