pub struct Frontmatter {Show 17 fields
pub id: String,
pub title: String,
pub state: String,
pub priority: u8,
pub effort: u8,
pub risk: u8,
pub author: Option<String>,
pub owner: Option<String>,
pub branch: Option<String>,
pub created_at: Option<DateTime<Utc>>,
pub updated_at: Option<DateTime<Utc>>,
pub focus_section: Option<String>,
pub epic: Option<String>,
pub target_branch: Option<String>,
pub depends_on: Option<Vec<String>>,
pub agent: Option<String>,
pub agent_overrides: HashMap<String, String>,
}Fields
id: Stringtitle: Stringstate: Stringpriority: u8effort: u8risk: u8owner: Option<String>branch: Option<String>created_at: Option<DateTime<Utc>>updated_at: Option<DateTime<Utc>>focus_section: Option<String>epic: Option<String>target_branch: Option<String>depends_on: Option<Vec<String>>agent: Option<String>agent_overrides: HashMap<String, String>Trait Implementations
Sourceimpl Clone for Frontmatter
impl Clone for Frontmatter
Sourcefn clone(&self) -> Frontmatter
fn clone(&self) -> Frontmatter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Frontmatter
impl Debug for Frontmatter
Sourceimpl<'de> Deserialize<'de> for Frontmatter
impl<'de> Deserialize<'de> for Frontmatter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Frontmatter
impl JsonSchema for Frontmatter
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Frontmatter
impl RefUnwindSafe for Frontmatter
impl Send for Frontmatter
impl Sync for Frontmatter
impl Unpin for Frontmatter
impl UnsafeUnpin for Frontmatter
impl UnwindSafe for Frontmatter